<?php

namespace App\Nova\Lenses;

use App\Models\Retailer;
use Auth;
use DB;
use Laravel\Nova\Fields\ID;
use Laravel\Nova\Fields\Select;
use Laravel\Nova\Fields\Text;
use Laravel\Nova\Fields\Textarea;
use Laravel\Nova\Http\Requests\LensRequest;
use Laravel\Nova\Http\Requests\NovaRequest;
use Laravel\Nova\Lenses\Lens;
use Vyuldashev\NovaMoneyField\Money;

class CompareProduct extends Lens
{

    public static $comparebelField;

    public static function query(LensRequest $request, $query)
    {
        $compare = DB::table('compare')->where('user_id', Auth::user()->id)->first();
        DB::table('compare')->where('user_id', Auth::user()->id)->delete();
        self::$comparebelField = $compare->field;
        if ($compare) {
            return $request->withOrdering($request->withFilters(
                $query->where('retailer_id', '!=', $compare->retailer)->orderBy('retailer_id', 'DESC')
            ));
        }
        return $request->withOrdering($request->withFilters(
            $query->where('id', -1)
        ));
    }

    /**
     * Get the fields available to the lens.
     *
     * @param  \Laravel\Nova\Http\Requests\NovaRequest  $request
     * @return array
     */
    public function fields(NovaRequest $request)
    {
        if (self::$comparebelField) {
            return [
                Text::make('Name')
                    ->sortable()
                    ->rules('required', 'max:255', 'min:2'),

                Select::make('Retailer', 'retailer_id')
                    ->options(
                        Retailer::pluck('name', 'id')->all()
                    )
                    ->rules('required')
                    ->placeholder('Choose retailer')
                    ->displayUsingLabels(),

                Text::make('SKU')
                    ->sortable()
                    ->rules('numeric'),

                Text::make(ucfirst(self::$comparebelField))
                    ->sortable()
                    ->rules('required'),
            ];
        }
        return [
            Text::make('Name')
                ->sortable()
                ->rules('required', 'max:255', 'min:2'),

            Select::make('Retailer', 'retailer_id')
                ->options(
                    Retailer::pluck('name', 'id')->all()
                )
                ->rules('required')
                ->placeholder('Choose retailer')
                ->displayUsingLabels(),

            Text::make('SKU')
                ->sortable()
                ->rules('numeric'),

            Money::make('Price')
                ->sortable()
                ->rules('required'),

            Textarea::make('Description')
                ->sortable()
                ->rules('required'),
        ];
    }

    /**
     * Get the cards available on the lens.
     *
     * @param  \Laravel\Nova\Http\Requests\NovaRequest  $request
     * @return array
     */
    public function cards(NovaRequest $request)
    {
        return [];
    }

    /**
     * Get the filters available for the lens.
     *
     * @param  \Laravel\Nova\Http\Requests\NovaRequest  $request
     * @return array
     */
    public function filters(NovaRequest $request)
    {
        return [];
    }

    /**
     * Get the actions available on the lens.
     *
     * @param  \Laravel\Nova\Http\Requests\NovaRequest  $request
     * @return array
     */
    public function actions(NovaRequest $request)
    {
        return [
            \App\Nova\Actions\CompareActionChangeValues::make()->standalone(),
        ];
    }

    /**
     * Get the URI key for the lens.
     *
     * @return string
     */
    public function uriKey()
    {
        return 'compare-product';
    }
}
